# TriggerEventProductRatePlanChargeRest

Specifies when to start billing the customer for the charge.  **Values**:   - `ContractEffective` is the date when the subscription's contract goes into effect and the charge is ready to be billed.   - `ServiceActivation` is the date when the services or products for a subscription have been activated and the customers have access.   - `CustomerAcceptance` is when the customer accepts the services or products for a subscription. 

## Enum

* `CONTRACTEFFECTIVE` (value: `'ContractEffective'`)

* `SERVICEACTIVATION` (value: `'ServiceActivation'`)

* `CUSTOMERACCEPTANCE` (value: `'CustomerAcceptance'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


